@@ -5,7 +5,7 @@
 # jointly copyrighted by participating institutions in DataONE. For
 # more information on DataONE, see our web site at http://dataone.org.
 #
-#   Copyright ${year}
+#   Copyright 2009-2014 DataONE
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,17 +19,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-'''Module d1_client.mnclient_1_1
+'''Module d1_client.mnclient_2_0
 ================================
 
 :Synopsis:
-  This module is currently a stub, as no functionality was added to the
-  MN APIs in 1.1.
+  This is where the new MN APIs in CCI 2.0 will be added.
+
+  This module implements the DataONE Member Node v2.0 API methods. It extends
+  MemberNodeClient_1_1, making 1.0 and 1.1 methods available as well.
 
   See the `Member Node APIs <http://mule1.dataone.org/ArchitectureDocs-current/apis/MN_APIs.html>`_
   details on how to use the methods in this class.
 
-:Created: 2011-01-21
+:Created: 2014-08-18
 :Author: DataONE (Vieglais, Dahl)
 '''
 
@@ -40,7 +42,7 @@ import sys
 # D1.
 try:
   import d1_common.const
-  import d1_common.types.generated.dataoneTypes_1_1 as dataoneTypes_1_1
+  import d1_common.types.generated.dataoneTypes_2_0 as dataoneTypes_2_0
   import d1_common.util
   import d1_common.date_time
 except ImportError as e:
@@ -49,10 +51,10 @@ except ImportError as e:
   raise
 
 # App.
-import d1baseclient_1_1
+import d1baseclient_2_0
 
 
-class MemberNodeClient(d1baseclient_1_1.DataONEBaseClient_1_1):
+class MemberNodeClient(d1baseclient_2_0.DataONEBaseClient_2_0):
   def __init__(self,
                base_url,
                timeout=d1_common.const.RESPONSE_TIMEOUT,
@@ -61,8 +63,8 @@ class MemberNodeClient(d1baseclient_1_1.DataONEBaseClient_1_1):
                key_path=None,
                strict=True,
                capture_response_body=False,
-               version='v1',
-               types=dataoneTypes_1_1):
+               version='v2',
+               types=dataoneTypes_2_0):
     '''Connect to a DataONE Member Node.
 
     :param base_url: DataONE Node REST service BaseURL
@@ -90,8 +92,9 @@ class MemberNodeClient(d1baseclient_1_1.DataONEBaseClient_1_1):
     :type types: PyXB
     :returns: None
     '''
-    d1baseclient_1_1.DataONEBaseClient_1_1.__init__(self, base_url=base_url,
+    d1baseclient_2_0.DataONEBaseClient_2_0.__init__(self, base_url=base_url,
       timeout=timeout, defaultHeaders=defaultHeaders, cert_path=cert_path,
       key_path=key_path, strict=strict,
       capture_response_body=capture_response_body, version=version, types=types)
     self.logger = logging.getLogger('MemberNodeClient')
+    self.logger.debug('Creating client for baseURL: {0}'.format(base_url))
