@@ -5,7 +5,7 @@
 # jointly copyrighted by participating institutions in DataONE. For
 # more information on DataONE, see our web site at http://dataone.org.
 #
-#   Copyright ${year}
+#   Copyright 2009-2014 DataONE
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,8 +23,8 @@
 ============================
 
 :Synopsis:
-  Map DataONE ObjectFormatIDs to mimetype and filename extension.
-  The mappings are provided in a CSV file.
+  Map DataONE ObjectFormatIDs to Content-Type and filename extension. The
+  mappings are provided in a CSV file. Raises KeyError for unknown values.
 :Created: 2012-10-25
 :Author: DataONE (Dahl)
 '''
@@ -61,7 +61,7 @@ class ObjectFormatInfo(Singleton):
     self.read_csv_file()
 
 
-  def mimetype_from_format_id(self, format_id):
+  def content_type_from_format_id(self, format_id):
     return self.format_id_map[format_id][0]
 
 
